@@ -157,7 +157,7 @@ def write_result_table(genome_results, output_file):
             values = [value for result in genome_result for value in result.values()]
             hit_subjects = [result['subject'] for result in genome_result]
             # add co-location result
-            if len(set(hit_subjects)) == 1:
+            if len(set(hit_subjects)) == 1 and set(hit_subjects) != set(['NA']):
                 row_items = [genome, 'Y'] # co-located
                 row_items.extend(values)
             else:
